@@ -1,3 +1,18 @@
+#
+# Copyright 2021 Splunk Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
 # -*- coding: utf-8 -*-
 """
 Provides the Field class containing all the field properties and a decorator 
@@ -36,6 +51,15 @@ class Field(object):
     def __str__(self):
         return str(self.name)
 
+    def __eq__(self, other: "Field"):
+        return self.__dict__ == other.__dict__
+
+    def __lt__(self, other: "Field"):
+        return self.name < other.name
+
+    def __repr__(self):
+        return f"<Field name={self.name}>"
+
     def get_type(self):
         return self.type
 
