@@ -16,7 +16,7 @@
 from .sample_event import SampleEvent
 from .rule import Rule, raise_warning
 from .sample_stanza import SampleStanza
-from .eventgen_parser import EventgenParser
+from .pytest_splunk_addon_data_parser import PytestSplunkAddonDataParser
 from .sample_event import SampleEvent
 from .sample_generator import SampleGenerator
 from .sample_xdist_generator import SampleXdistGenerator
